==> hbase-2.5.13-src.tar.gz: hbase-2.5.13/hbase-server/src/main/java/org/apache/hadoop/hbase/regionserver/http/RSStatusServlet.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.regionserver.http;

import java.io.IOException;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.hadoop.hbase.regionserver.HRegionServer;
import org.apache.hadoop.hbase.tmpl.regionserver.RSStatusTmpl;
import org.apache.yetus.audience.InterfaceAudience;

@InterfaceAudience.Private
public class RSStatusServlet extends HttpServlet {
  private static final long serialVersionUID = 1L;

  @Override
  protected void doGet(HttpServletRequest req, HttpServletResponse resp)
    throws ServletException, IOException {
    HRegionServer hrs =
      (HRegionServer) getServletContext().getAttribute(HRegionServer.REGIONSERVER);
    assert hrs != null : "No RS in context!";

    resp.setContentType("text/html");

    if (!hrs.isOnline()) {
      resp.getWriter().write("The RegionServer is initializing!");
      resp.getWriter().close();
      return;
    }

    RSStatusTmpl tmpl = new RSStatusTmpl();
    if (req.getParameter("format") != null) tmpl.setFormat(req.getParameter("format"));
    if (req.getParameter("filter") != null) tmpl.setFilter(req.getParameter("filter"));
    if (req.getParameter("bcn") != null) tmpl.setBcn(req.getParameter("bcn"));
    if (req.getParameter("bcv") != null) tmpl.setBcv(req.getParameter("bcv"));
    tmpl.render(resp.getWriter(), hrs);
  }
}

==> hbase-2.6.3-src.tar.gz: hbase-2.6.3/hbase-server/src/main/java/org/apache/hadoop/hbase/regionserver/http/RSStatusServlet.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.regionserver.http;

import java.io.IOException;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.hadoop.hbase.regionserver.HRegionServer;
import org.apache.hadoop.hbase.tmpl.regionserver.RSStatusTmpl;
import org.apache.yetus.audience.InterfaceAudience;

@InterfaceAudience.Private
public class RSStatusServlet extends HttpServlet {
  private static final long serialVersionUID = 1L;

  @Override
  protected void doGet(HttpServletRequest req, HttpServletResponse resp)
    throws ServletException, IOException {
    HRegionServer hrs =
      (HRegionServer) getServletContext().getAttribute(HRegionServer.REGIONSERVER);
    assert hrs != null : "No RS in context!";

    String format = req.getParameter("format");
    if ("json".equals(format)) {
      resp.setContentType("application/json");
    } else {
      resp.setContentType("text/html");
    }

    if (!hrs.isOnline()) {
      resp.getWriter().write("The RegionServer is initializing!");
      resp.getWriter().close();
      return;
    }

    RSStatusTmpl tmpl = new RSStatusTmpl();
    if (format != null) tmpl.setFormat(format);
    if (req.getParameter("filter") != null) tmpl.setFilter(req.getParameter("filter"));
    if (req.getParameter("bcn") != null) tmpl.setBcn(req.getParameter("bcn"));
    if (req.getParameter("bcv") != null) tmpl.setBcv(req.getParameter("bcv"));
    tmpl.render(resp.getWriter(), hrs);
  }
}
